# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20027DataStoragePolicies(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'policy_name': 'str',
        'replicas': 'int',
        'sp_type_id': 'int',
        'storage_policy_type': 'str',
        'data_fragments': 'int',
        'parity_fragments': 'int'
    }

    attribute_map = {
        'display_name': 'display_name',
        'policy_name': 'policy_name',
        'replicas': 'replicas',
        'sp_type_id': 'sp_type_id',
        'storage_policy_type': 'storage_policy_type',
        'data_fragments': 'data_fragments',
        'parity_fragments': 'parity_fragments'
    }

    def __init__(self, display_name=None, policy_name=None, replicas=None, sp_type_id=None, storage_policy_type=None, data_fragments=None, parity_fragments=None, _configuration=None):  # noqa: E501
        """InlineResponse20027DataStoragePolicies - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._display_name = None
        self._policy_name = None
        self._replicas = None
        self._sp_type_id = None
        self._storage_policy_type = None
        self._data_fragments = None
        self._parity_fragments = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        if policy_name is not None:
            self.policy_name = policy_name
        if replicas is not None:
            self.replicas = replicas
        if sp_type_id is not None:
            self.sp_type_id = sp_type_id
        if storage_policy_type is not None:
            self.storage_policy_type = storage_policy_type
        if data_fragments is not None:
            self.data_fragments = data_fragments
        if parity_fragments is not None:
            self.parity_fragments = parity_fragments

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20027DataStoragePolicies.  # noqa: E501


        :return: The display_name of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20027DataStoragePolicies.


        :param display_name: The display_name of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def policy_name(self):
        """Gets the policy_name of this InlineResponse20027DataStoragePolicies.  # noqa: E501


        :return: The policy_name of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._policy_name

    @policy_name.setter
    def policy_name(self, policy_name):
        """Sets the policy_name of this InlineResponse20027DataStoragePolicies.


        :param policy_name: The policy_name of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :type: str
        """

        self._policy_name = policy_name

    @property
    def replicas(self):
        """Gets the replicas of this InlineResponse20027DataStoragePolicies.  # noqa: E501


        :return: The replicas of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :rtype: int
        """
        return self._replicas

    @replicas.setter
    def replicas(self, replicas):
        """Sets the replicas of this InlineResponse20027DataStoragePolicies.


        :param replicas: The replicas of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :type: int
        """

        self._replicas = replicas

    @property
    def sp_type_id(self):
        """Gets the sp_type_id of this InlineResponse20027DataStoragePolicies.  # noqa: E501


        :return: The sp_type_id of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :rtype: int
        """
        return self._sp_type_id

    @sp_type_id.setter
    def sp_type_id(self, sp_type_id):
        """Sets the sp_type_id of this InlineResponse20027DataStoragePolicies.


        :param sp_type_id: The sp_type_id of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :type: int
        """

        self._sp_type_id = sp_type_id

    @property
    def storage_policy_type(self):
        """Gets the storage_policy_type of this InlineResponse20027DataStoragePolicies.  # noqa: E501


        :return: The storage_policy_type of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._storage_policy_type

    @storage_policy_type.setter
    def storage_policy_type(self, storage_policy_type):
        """Sets the storage_policy_type of this InlineResponse20027DataStoragePolicies.


        :param storage_policy_type: The storage_policy_type of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :type: str
        """

        self._storage_policy_type = storage_policy_type

    @property
    def data_fragments(self):
        """Gets the data_fragments of this InlineResponse20027DataStoragePolicies.  # noqa: E501


        :return: The data_fragments of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :rtype: int
        """
        return self._data_fragments

    @data_fragments.setter
    def data_fragments(self, data_fragments):
        """Sets the data_fragments of this InlineResponse20027DataStoragePolicies.


        :param data_fragments: The data_fragments of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :type: int
        """

        self._data_fragments = data_fragments

    @property
    def parity_fragments(self):
        """Gets the parity_fragments of this InlineResponse20027DataStoragePolicies.  # noqa: E501


        :return: The parity_fragments of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :rtype: int
        """
        return self._parity_fragments

    @parity_fragments.setter
    def parity_fragments(self, parity_fragments):
        """Sets the parity_fragments of this InlineResponse20027DataStoragePolicies.


        :param parity_fragments: The parity_fragments of this InlineResponse20027DataStoragePolicies.  # noqa: E501
        :type: int
        """

        self._parity_fragments = parity_fragments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20027DataStoragePolicies, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20027DataStoragePolicies):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20027DataStoragePolicies):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200109ResponseRemotePools(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'remote_display_name': 'str',
        'capacity': 'str',
        'free_capacity': 'str',
        'mode': 'str',
        'stripe_size': 'str',
        'version': 'str'
    }

    attribute_map = {
        'name': 'name',
        'remote_display_name': 'remote_display_name',
        'capacity': 'capacity',
        'free_capacity': 'free_capacity',
        'mode': 'mode',
        'stripe_size': 'stripe_size',
        'version': 'version'
    }

    def __init__(self, name=None, remote_display_name=None, capacity=None, free_capacity=None, mode=None, stripe_size=None, version=None, _configuration=None):  # noqa: E501
        """InlineResponse200109ResponseRemotePools - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._remote_display_name = None
        self._capacity = None
        self._free_capacity = None
        self._mode = None
        self._stripe_size = None
        self._version = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if remote_display_name is not None:
            self.remote_display_name = remote_display_name
        if capacity is not None:
            self.capacity = capacity
        if free_capacity is not None:
            self.free_capacity = free_capacity
        if mode is not None:
            self.mode = mode
        if stripe_size is not None:
            self.stripe_size = stripe_size
        if version is not None:
            self.version = version

    @property
    def name(self):
        """Gets the name of this InlineResponse200109ResponseRemotePools.  # noqa: E501


        :return: The name of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200109ResponseRemotePools.


        :param name: The name of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def remote_display_name(self):
        """Gets the remote_display_name of this InlineResponse200109ResponseRemotePools.  # noqa: E501


        :return: The remote_display_name of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :rtype: str
        """
        return self._remote_display_name

    @remote_display_name.setter
    def remote_display_name(self, remote_display_name):
        """Sets the remote_display_name of this InlineResponse200109ResponseRemotePools.


        :param remote_display_name: The remote_display_name of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :type: str
        """

        self._remote_display_name = remote_display_name

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse200109ResponseRemotePools.  # noqa: E501


        :return: The capacity of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :rtype: str
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse200109ResponseRemotePools.


        :param capacity: The capacity of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :type: str
        """

        self._capacity = capacity

    @property
    def free_capacity(self):
        """Gets the free_capacity of this InlineResponse200109ResponseRemotePools.  # noqa: E501


        :return: The free_capacity of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :rtype: str
        """
        return self._free_capacity

    @free_capacity.setter
    def free_capacity(self, free_capacity):
        """Sets the free_capacity of this InlineResponse200109ResponseRemotePools.


        :param free_capacity: The free_capacity of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :type: str
        """

        self._free_capacity = free_capacity

    @property
    def mode(self):
        """Gets the mode of this InlineResponse200109ResponseRemotePools.  # noqa: E501


        :return: The mode of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this InlineResponse200109ResponseRemotePools.


        :param mode: The mode of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def stripe_size(self):
        """Gets the stripe_size of this InlineResponse200109ResponseRemotePools.  # noqa: E501


        :return: The stripe_size of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :rtype: str
        """
        return self._stripe_size

    @stripe_size.setter
    def stripe_size(self, stripe_size):
        """Sets the stripe_size of this InlineResponse200109ResponseRemotePools.


        :param stripe_size: The stripe_size of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :type: str
        """

        self._stripe_size = stripe_size

    @property
    def version(self):
        """Gets the version of this InlineResponse200109ResponseRemotePools.  # noqa: E501


        :return: The version of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InlineResponse200109ResponseRemotePools.


        :param version: The version of this InlineResponse200109ResponseRemotePools.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200109ResponseRemotePools, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200109ResponseRemotePools):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200109ResponseRemotePools):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200135Vcs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'lb_group_owner': 'bool',
        'fe_ipv4': 'str',
        'fe_ipv6': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'lb_group_owner': 'lb_group_owner',
        'fe_ipv4': 'fe_ipv4',
        'fe_ipv6': 'fe_ipv6'
    }

    def __init__(self, id=None, name=None, lb_group_owner=None, fe_ipv4=None, fe_ipv6=None, _configuration=None):  # noqa: E501
        """InlineResponse200135Vcs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._lb_group_owner = None
        self._fe_ipv4 = None
        self._fe_ipv6 = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if lb_group_owner is not None:
            self.lb_group_owner = lb_group_owner
        if fe_ipv4 is not None:
            self.fe_ipv4 = fe_ipv4
        if fe_ipv6 is not None:
            self.fe_ipv6 = fe_ipv6

    @property
    def id(self):
        """Gets the id of this InlineResponse200135Vcs.  # noqa: E501


        :return: The id of this InlineResponse200135Vcs.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse200135Vcs.


        :param id: The id of this InlineResponse200135Vcs.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this InlineResponse200135Vcs.  # noqa: E501


        :return: The name of this InlineResponse200135Vcs.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200135Vcs.


        :param name: The name of this InlineResponse200135Vcs.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def lb_group_owner(self):
        """Gets the lb_group_owner of this InlineResponse200135Vcs.  # noqa: E501


        :return: The lb_group_owner of this InlineResponse200135Vcs.  # noqa: E501
        :rtype: bool
        """
        return self._lb_group_owner

    @lb_group_owner.setter
    def lb_group_owner(self, lb_group_owner):
        """Sets the lb_group_owner of this InlineResponse200135Vcs.


        :param lb_group_owner: The lb_group_owner of this InlineResponse200135Vcs.  # noqa: E501
        :type: bool
        """

        self._lb_group_owner = lb_group_owner

    @property
    def fe_ipv4(self):
        """Gets the fe_ipv4 of this InlineResponse200135Vcs.  # noqa: E501


        :return: The fe_ipv4 of this InlineResponse200135Vcs.  # noqa: E501
        :rtype: str
        """
        return self._fe_ipv4

    @fe_ipv4.setter
    def fe_ipv4(self, fe_ipv4):
        """Sets the fe_ipv4 of this InlineResponse200135Vcs.


        :param fe_ipv4: The fe_ipv4 of this InlineResponse200135Vcs.  # noqa: E501
        :type: str
        """

        self._fe_ipv4 = fe_ipv4

    @property
    def fe_ipv6(self):
        """Gets the fe_ipv6 of this InlineResponse200135Vcs.  # noqa: E501


        :return: The fe_ipv6 of this InlineResponse200135Vcs.  # noqa: E501
        :rtype: str
        """
        return self._fe_ipv6

    @fe_ipv6.setter
    def fe_ipv6(self, fe_ipv6):
        """Sets the fe_ipv6 of this InlineResponse200135Vcs.


        :param fe_ipv6: The fe_ipv6 of this InlineResponse200135Vcs.  # noqa: E501
        :type: str
        """

        self._fe_ipv6 = fe_ipv6

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200135Vcs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200135Vcs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200135Vcs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class StorageNodesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def evacoate_vc_from_sn(self, cloud_name, id, evacoate_vc_from_sn, **kwargs):  # noqa: E501
        """evacoate_vc_from_sn  # noqa: E501

        Evacuate a Storage Node from all Virtual Controllers. The Virtual Controllers will be deleted and re_spawned on a different Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.evacoate_vc_from_sn(cloud_name, id, evacoate_vc_from_sn, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param EvacoateVcFromSn evacoate_vc_from_sn: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.evacoate_vc_from_sn_with_http_info(cloud_name, id, evacoate_vc_from_sn, **kwargs)  # noqa: E501
        else:
            (data) = self.evacoate_vc_from_sn_with_http_info(cloud_name, id, evacoate_vc_from_sn, **kwargs)  # noqa: E501
            return data

    def evacoate_vc_from_sn_with_http_info(self, cloud_name, id, evacoate_vc_from_sn, **kwargs):  # noqa: E501
        """evacoate_vc_from_sn  # noqa: E501

        Evacuate a Storage Node from all Virtual Controllers. The Virtual Controllers will be deleted and re_spawned on a different Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.evacoate_vc_from_sn_with_http_info(cloud_name, id, evacoate_vc_from_sn, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param EvacoateVcFromSn evacoate_vc_from_sn: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id', 'evacoate_vc_from_sn']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method evacoate_vc_from_sn" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `evacoate_vc_from_sn`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `evacoate_vc_from_sn`")  # noqa: E501
        # verify the required parameter 'evacoate_vc_from_sn' is set
        if self.api_client.client_side_validation and ('evacoate_vc_from_sn' not in params or
                                                       params['evacoate_vc_from_sn'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `evacoate_vc_from_sn` when calling `evacoate_vc_from_sn`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'evacoate_vc_from_sn' in params:
            body_params = params['evacoate_vc_from_sn']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/evacuate_vcs.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def evacoated_drives_from_sn(self, cloud_name, id, **kwargs):  # noqa: E501
        """evacoated_drives_from_sn  # noqa: E501

        Evacuate a Storage Node from all allocated drives. Replacement drives for the affected VPSA will be allocated from other Storage Nodes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.evacoated_drives_from_sn(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.evacoated_drives_from_sn_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.evacoated_drives_from_sn_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def evacoated_drives_from_sn_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """evacoated_drives_from_sn  # noqa: E501

        Evacuate a Storage Node from all allocated drives. Replacement drives for the affected VPSA will be allocated from other Storage Nodes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.evacoated_drives_from_sn_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method evacoated_drives_from_sn" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `evacoated_drives_from_sn`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `evacoated_drives_from_sn`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/evacuate_drives.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_storage_nodes(self, cloud_name, **kwargs):  # noqa: E501
        """get_all_storage_nodes  # noqa: E501

        Returns a list of all Storage Nodes in a Zadara Storage Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_storage_nodes(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_storage_nodes_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_storage_nodes_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def get_all_storage_nodes_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """get_all_storage_nodes  # noqa: E501

        Returns a list of all Storage Nodes in a Zadara Storage Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_storage_nodes_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_storage_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_all_storage_nodes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20038',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_schedulable_services_status(self, cloud_name, node_name, **kwargs):  # noqa: E501
        """get_schedulable_services_status  # noqa: E501

        Returns schedulable services status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_schedulable_services_status(cloud_name, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_schedulable_services_status_with_http_info(cloud_name, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_schedulable_services_status_with_http_info(cloud_name, node_name, **kwargs)  # noqa: E501
            return data

    def get_schedulable_services_status_with_http_info(self, cloud_name, node_name, **kwargs):  # noqa: E501
        """get_schedulable_services_status  # noqa: E501

        Returns schedulable services status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_schedulable_services_status_with_http_info(cloud_name, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_schedulable_services_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_schedulable_services_status`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if self.api_client.client_side_validation and ('node_name' not in params or
                                                       params['node_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `node_name` when calling `get_schedulable_services_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{node_name}/get_scheduling_status.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20044',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sn_cache_partitions_details(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_sn_cache_partitions_details  # noqa: E501

        Returns the details for a Storage Node's cache partitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sn_cache_partitions_details(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sn_cache_partitions_details_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sn_cache_partitions_details_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_sn_cache_partitions_details_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_sn_cache_partitions_details  # noqa: E501

        Returns the details for a Storage Node's cache partitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sn_cache_partitions_details_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sn_cache_partitions_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_sn_cache_partitions_details`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_sn_cache_partitions_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/cache_partitions.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20041',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sn_conf(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_sn_conf  # noqa: E501

        Check the configuration for a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sn_conf(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sn_conf_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sn_conf_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_sn_conf_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_sn_conf  # noqa: E501

        Check the configuration for a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sn_conf_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sn_conf" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_sn_conf`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_sn_conf`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/check_configuration.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20043',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sn_vcs_details(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_sn_vcs_details  # noqa: E501

        Returns the details of the Virtual Controllers which are running inside a Storage Node's.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sn_vcs_details(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sn_vcs_details_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sn_vcs_details_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_sn_vcs_details_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_sn_vcs_details  # noqa: E501

        Returns the details of the Virtual Controllers which are running inside a Storage Node's.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sn_vcs_details_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sn_vcs_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_sn_vcs_details`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_sn_vcs_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/virtual_controllers.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20042',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_storage_node(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_storage_node  # noqa: E501

        Returns a single Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_storage_node(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_storage_node_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_storage_node_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_storage_node_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_storage_node  # noqa: E501

        Returns a single Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_storage_node_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_storage_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_storage_node`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_storage_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20039',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_storage_node_drives(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_storage_node_drives  # noqa: E501

        Returns the details for a Storage Node's drives.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_storage_node_drives(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20040
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_storage_node_drives_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_storage_node_drives_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_storage_node_drives_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_storage_node_drives  # noqa: E501

        Returns the details for a Storage Node's drives.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_storage_node_drives_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20040
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_storage_node_drives" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_storage_node_drives`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_storage_node_drives`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/drives.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20040',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_sn_new_drives(self, cloud_name, id, **kwargs):  # noqa: E501
        """import_sn_new_drives  # noqa: E501

        Import new drives for a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_sn_new_drives(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_sn_new_drives_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.import_sn_new_drives_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def import_sn_new_drives_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """import_sn_new_drives  # noqa: E501

        Import new drives for a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_sn_new_drives_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_sn_new_drives" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `import_sn_new_drives`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `import_sn_new_drives`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/import_drives.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def install_sn(self, cloud_name, node_name, install_sn, **kwargs):  # noqa: E501
        """install_sn  # noqa: E501

        Install a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.install_sn(cloud_name, node_name, install_sn, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param InstallSn install_sn: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.install_sn_with_http_info(cloud_name, node_name, install_sn, **kwargs)  # noqa: E501
        else:
            (data) = self.install_sn_with_http_info(cloud_name, node_name, install_sn, **kwargs)  # noqa: E501
            return data

    def install_sn_with_http_info(self, cloud_name, node_name, install_sn, **kwargs):  # noqa: E501
        """install_sn  # noqa: E501

        Install a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.install_sn_with_http_info(cloud_name, node_name, install_sn, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param InstallSn install_sn: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'node_name', 'install_sn']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method install_sn" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `install_sn`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if self.api_client.client_side_validation and ('node_name' not in params or
                                                       params['node_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `node_name` when calling `install_sn`")  # noqa: E501
        # verify the required parameter 'install_sn' is set
        if self.api_client.client_side_validation and ('install_sn' not in params or
                                                       params['install_sn'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `install_sn` when calling `install_sn`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'install_sn' in params:
            body_params = params['install_sn']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{node_name}/install.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def license_storage_node(self, cloud_name, id, license_storage_node, **kwargs):  # noqa: E501
        """license_storage_node  # noqa: E501

        Activate a license key for a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.license_storage_node(cloud_name, id, license_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param LicenseStorageNode license_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.license_storage_node_with_http_info(cloud_name, id, license_storage_node, **kwargs)  # noqa: E501
        else:
            (data) = self.license_storage_node_with_http_info(cloud_name, id, license_storage_node, **kwargs)  # noqa: E501
            return data

    def license_storage_node_with_http_info(self, cloud_name, id, license_storage_node, **kwargs):  # noqa: E501
        """license_storage_node  # noqa: E501

        Activate a license key for a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.license_storage_node_with_http_info(cloud_name, id, license_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param LicenseStorageNode license_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id', 'license_storage_node']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method license_storage_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `license_storage_node`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `license_storage_node`")  # noqa: E501
        # verify the required parameter 'license_storage_node' is set
        if self.api_client.client_side_validation and ('license_storage_node' not in params or
                                                       params['license_storage_node'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `license_storage_node` when calling `license_storage_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'license_storage_node' in params:
            body_params = params['license_storage_node']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/license.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reboot_storage_node(self, cloud_name, id, reboot_storage_node, **kwargs):  # noqa: E501
        """reboot_storage_node  # noqa: E501

        Reboot a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reboot_storage_node(cloud_name, id, reboot_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param RebootStorageNode reboot_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reboot_storage_node_with_http_info(cloud_name, id, reboot_storage_node, **kwargs)  # noqa: E501
        else:
            (data) = self.reboot_storage_node_with_http_info(cloud_name, id, reboot_storage_node, **kwargs)  # noqa: E501
            return data

    def reboot_storage_node_with_http_info(self, cloud_name, id, reboot_storage_node, **kwargs):  # noqa: E501
        """reboot_storage_node  # noqa: E501

        Reboot a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reboot_storage_node_with_http_info(cloud_name, id, reboot_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param RebootStorageNode reboot_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id', 'reboot_storage_node']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reboot_storage_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `reboot_storage_node`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `reboot_storage_node`")  # noqa: E501
        # verify the required parameter 'reboot_storage_node' is set
        if self.api_client.client_side_validation and ('reboot_storage_node' not in params or
                                                       params['reboot_storage_node'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reboot_storage_node` when calling `reboot_storage_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reboot_storage_node' in params:
            body_params = params['reboot_storage_node']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/reboot.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def refresh_sn_license_status(self, cloud_name, id, **kwargs):  # noqa: E501
        """refresh_sn_license_status  # noqa: E501

        Refresh a Storage Node's license status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refresh_sn_license_status(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.refresh_sn_license_status_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.refresh_sn_license_status_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def refresh_sn_license_status_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """refresh_sn_license_status  # noqa: E501

        Refresh a Storage Node's license status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refresh_sn_license_status_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method refresh_sn_license_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `refresh_sn_license_status`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `refresh_sn_license_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/refresh_license.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_scheduling_status(self, cloud_name, node_name, set_scheduling_status, **kwargs):  # noqa: E501
        """set_scheduling_status  # noqa: E501

        Enable/Disable node's drive/vc schedualing.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_scheduling_status(cloud_name, node_name, set_scheduling_status, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param SetSchedulingStatus set_scheduling_status: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_scheduling_status_with_http_info(cloud_name, node_name, set_scheduling_status, **kwargs)  # noqa: E501
        else:
            (data) = self.set_scheduling_status_with_http_info(cloud_name, node_name, set_scheduling_status, **kwargs)  # noqa: E501
            return data

    def set_scheduling_status_with_http_info(self, cloud_name, node_name, set_scheduling_status, **kwargs):  # noqa: E501
        """set_scheduling_status  # noqa: E501

        Enable/Disable node's drive/vc schedualing.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_scheduling_status_with_http_info(cloud_name, node_name, set_scheduling_status, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param SetSchedulingStatus set_scheduling_status: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'node_name', 'set_scheduling_status']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_scheduling_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `set_scheduling_status`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if self.api_client.client_side_validation and ('node_name' not in params or
                                                       params['node_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `node_name` when calling `set_scheduling_status`")  # noqa: E501
        # verify the required parameter 'set_scheduling_status' is set
        if self.api_client.client_side_validation and ('set_scheduling_status' not in params or
                                                       params['set_scheduling_status'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `set_scheduling_status` when calling `set_scheduling_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'set_scheduling_status' in params:
            body_params = params['set_scheduling_status']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{node_name}/set_scheduling_status.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def shutdown_storage_node(self, cloud_name, id, shutdown_storage_node, **kwargs):  # noqa: E501
        """shutdown_storage_node  # noqa: E501

        Shutdown a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.shutdown_storage_node(cloud_name, id, shutdown_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param ShutdownStorageNode shutdown_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.shutdown_storage_node_with_http_info(cloud_name, id, shutdown_storage_node, **kwargs)  # noqa: E501
        else:
            (data) = self.shutdown_storage_node_with_http_info(cloud_name, id, shutdown_storage_node, **kwargs)  # noqa: E501
            return data

    def shutdown_storage_node_with_http_info(self, cloud_name, id, shutdown_storage_node, **kwargs):  # noqa: E501
        """shutdown_storage_node  # noqa: E501

        Shutdown a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.shutdown_storage_node_with_http_info(cloud_name, id, shutdown_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param ShutdownStorageNode shutdown_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id', 'shutdown_storage_node']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method shutdown_storage_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `shutdown_storage_node`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `shutdown_storage_node`")  # noqa: E501
        # verify the required parameter 'shutdown_storage_node' is set
        if self.api_client.client_side_validation and ('shutdown_storage_node' not in params or
                                                       params['shutdown_storage_node'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `shutdown_storage_node` when calling `shutdown_storage_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'shutdown_storage_node' in params:
            body_params = params['shutdown_storage_node']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/shutdown.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upgrade_sn(self, cloud_name, node_name, upgrade_sn, **kwargs):  # noqa: E501
        """upgrade_sn  # noqa: E501

        Upgrade a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_sn(cloud_name, node_name, upgrade_sn, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param UpgradeSn upgrade_sn: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upgrade_sn_with_http_info(cloud_name, node_name, upgrade_sn, **kwargs)  # noqa: E501
        else:
            (data) = self.upgrade_sn_with_http_info(cloud_name, node_name, upgrade_sn, **kwargs)  # noqa: E501
            return data

    def upgrade_sn_with_http_info(self, cloud_name, node_name, upgrade_sn, **kwargs):  # noqa: E501
        """upgrade_sn  # noqa: E501

        Upgrade a Storage Node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_sn_with_http_info(cloud_name, node_name, upgrade_sn, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param UpgradeSn upgrade_sn: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'node_name', 'upgrade_sn']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upgrade_sn" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `upgrade_sn`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if self.api_client.client_side_validation and ('node_name' not in params or
                                                       params['node_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `node_name` when calling `upgrade_sn`")  # noqa: E501
        # verify the required parameter 'upgrade_sn' is set
        if self.api_client.client_side_validation and ('upgrade_sn' not in params or
                                                       params['upgrade_sn'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `upgrade_sn` when calling `upgrade_sn`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'upgrade_sn' in params:
            body_params = params['upgrade_sn']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{node_name}/upgrade.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upgrade_sn_megaraid_and_drives_firmware(self, cloud_name, node_name, upgrade_sn_megaraid_and_drives_firmware, **kwargs):  # noqa: E501
        """upgrade_sn_megaraid_and_drives_firmware  # noqa: E501

        Upgrade a Storage Node MegaRaid/Drives firmware.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_sn_megaraid_and_drives_firmware(cloud_name, node_name, upgrade_sn_megaraid_and_drives_firmware, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param UpgradeSnMegaraidAndDrivesFirmware upgrade_sn_megaraid_and_drives_firmware: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upgrade_sn_megaraid_and_drives_firmware_with_http_info(cloud_name, node_name, upgrade_sn_megaraid_and_drives_firmware, **kwargs)  # noqa: E501
        else:
            (data) = self.upgrade_sn_megaraid_and_drives_firmware_with_http_info(cloud_name, node_name, upgrade_sn_megaraid_and_drives_firmware, **kwargs)  # noqa: E501
            return data

    def upgrade_sn_megaraid_and_drives_firmware_with_http_info(self, cloud_name, node_name, upgrade_sn_megaraid_and_drives_firmware, **kwargs):  # noqa: E501
        """upgrade_sn_megaraid_and_drives_firmware  # noqa: E501

        Upgrade a Storage Node MegaRaid/Drives firmware.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_sn_megaraid_and_drives_firmware_with_http_info(cloud_name, node_name, upgrade_sn_megaraid_and_drives_firmware, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str node_name: (required)
        :param UpgradeSnMegaraidAndDrivesFirmware upgrade_sn_megaraid_and_drives_firmware: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'node_name', 'upgrade_sn_megaraid_and_drives_firmware']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upgrade_sn_megaraid_and_drives_firmware" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `upgrade_sn_megaraid_and_drives_firmware`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if self.api_client.client_side_validation and ('node_name' not in params or
                                                       params['node_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `node_name` when calling `upgrade_sn_megaraid_and_drives_firmware`")  # noqa: E501
        # verify the required parameter 'upgrade_sn_megaraid_and_drives_firmware' is set
        if self.api_client.client_side_validation and ('upgrade_sn_megaraid_and_drives_firmware' not in params or
                                                       params['upgrade_sn_megaraid_and_drives_firmware'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `upgrade_sn_megaraid_and_drives_firmware` when calling `upgrade_sn_megaraid_and_drives_firmware`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'upgrade_sn_megaraid_and_drives_firmware' in params:
            body_params = params['upgrade_sn_megaraid_and_drives_firmware']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{node_name}/upgrade_fw.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def zsnap_storage_node(self, cloud_name, id, zsnap_storage_node, **kwargs):  # noqa: E501
        """zsnap_storage_node  # noqa: E501

        Create a Storage Node Zsnap.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zsnap_storage_node(cloud_name, id, zsnap_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param ZsnapStorageNode zsnap_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.zsnap_storage_node_with_http_info(cloud_name, id, zsnap_storage_node, **kwargs)  # noqa: E501
        else:
            (data) = self.zsnap_storage_node_with_http_info(cloud_name, id, zsnap_storage_node, **kwargs)  # noqa: E501
            return data

    def zsnap_storage_node_with_http_info(self, cloud_name, id, zsnap_storage_node, **kwargs):  # noqa: E501
        """zsnap_storage_node  # noqa: E501

        Create a Storage Node Zsnap.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.zsnap_storage_node_with_http_info(cloud_name, id, zsnap_storage_node, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param ZsnapStorageNode zsnap_storage_node: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id', 'zsnap_storage_node']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method zsnap_storage_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `zsnap_storage_node`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `zsnap_storage_node`")  # noqa: E501
        # verify the required parameter 'zsnap_storage_node' is set
        if self.api_client.client_side_validation and ('zsnap_storage_node' not in params or
                                                       params['zsnap_storage_node'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `zsnap_storage_node` when calling `zsnap_storage_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'zsnap_storage_node' in params:
            body_params = params['zsnap_storage_node']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/nodes/{id}/zsnap.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdateVolPerfThreshold(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'read_iops_limit': 'int',
        'read_mbps_limit': 'int',
        'read_latency_limit': 'int',
        'write_iops_limit': 'int',
        'write_mbps_limit': 'int',
        'write_latency_limit': 'int'
    }

    attribute_map = {
        'read_iops_limit': 'read_iops_limit',
        'read_mbps_limit': 'read_mbps_limit',
        'read_latency_limit': 'read_latency_limit',
        'write_iops_limit': 'write_iops_limit',
        'write_mbps_limit': 'write_mbps_limit',
        'write_latency_limit': 'write_latency_limit'
    }

    def __init__(self, read_iops_limit=None, read_mbps_limit=None, read_latency_limit=None, write_iops_limit=None, write_mbps_limit=None, write_latency_limit=None, _configuration=None):  # noqa: E501
        """UpdateVolPerfThreshold - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._read_iops_limit = None
        self._read_mbps_limit = None
        self._read_latency_limit = None
        self._write_iops_limit = None
        self._write_mbps_limit = None
        self._write_latency_limit = None
        self.discriminator = None

        if read_iops_limit is not None:
            self.read_iops_limit = read_iops_limit
        if read_mbps_limit is not None:
            self.read_mbps_limit = read_mbps_limit
        if read_latency_limit is not None:
            self.read_latency_limit = read_latency_limit
        if write_iops_limit is not None:
            self.write_iops_limit = write_iops_limit
        if write_mbps_limit is not None:
            self.write_mbps_limit = write_mbps_limit
        if write_latency_limit is not None:
            self.write_latency_limit = write_latency_limit

    @property
    def read_iops_limit(self):
        """Gets the read_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average read IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :return: The read_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._read_iops_limit

    @read_iops_limit.setter
    def read_iops_limit(self, read_iops_limit):
        """Sets the read_iops_limit of this UpdateVolPerfThreshold.

        Alert me when the average read IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :param read_iops_limit: The read_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._read_iops_limit = read_iops_limit

    @property
    def read_mbps_limit(self):
        """Gets the read_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average read throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :return: The read_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._read_mbps_limit

    @read_mbps_limit.setter
    def read_mbps_limit(self, read_mbps_limit):
        """Sets the read_mbps_limit of this UpdateVolPerfThreshold.

        Alert me when the average read throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :param read_mbps_limit: The read_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._read_mbps_limit = read_mbps_limit

    @property
    def read_latency_limit(self):
        """Gets the read_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average read latency for this volume exceeds this number of ms.  # noqa: E501

        :return: The read_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._read_latency_limit

    @read_latency_limit.setter
    def read_latency_limit(self, read_latency_limit):
        """Sets the read_latency_limit of this UpdateVolPerfThreshold.

        Alert me when the average read latency for this volume exceeds this number of ms.  # noqa: E501

        :param read_latency_limit: The read_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._read_latency_limit = read_latency_limit

    @property
    def write_iops_limit(self):
        """Gets the write_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average write IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :return: The write_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._write_iops_limit

    @write_iops_limit.setter
    def write_iops_limit(self, write_iops_limit):
        """Sets the write_iops_limit of this UpdateVolPerfThreshold.

        Alert me when the average write IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :param write_iops_limit: The write_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._write_iops_limit = write_iops_limit

    @property
    def write_mbps_limit(self):
        """Gets the write_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average write throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :return: The write_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._write_mbps_limit

    @write_mbps_limit.setter
    def write_mbps_limit(self, write_mbps_limit):
        """Sets the write_mbps_limit of this UpdateVolPerfThreshold.

        Alert me when the average write throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :param write_mbps_limit: The write_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._write_mbps_limit = write_mbps_limit

    @property
    def write_latency_limit(self):
        """Gets the write_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average write latency for this volume exceeds this number of ms.  # noqa: E501

        :return: The write_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._write_latency_limit

    @write_latency_limit.setter
    def write_latency_limit(self, write_latency_limit):
        """Sets the write_latency_limit of this UpdateVolPerfThreshold.

        Alert me when the average write latency for this volume exceeds this number of ms.  # noqa: E501

        :param write_latency_limit: The write_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._write_latency_limit = write_latency_limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateVolPerfThreshold, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVolPerfThreshold):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateVolPerfThreshold):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200131Drives(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_name': 'str',
        'node': 'str',
        'size': 'int',
        'type': 'str',
        'uuid': 'str',
        'address': 'str',
        'location': 'str',
        'product_id': 'str',
        'drive_id': 'str',
        'partition_count_degraded': 'str',
        'partition_count_critical': 'str'
    }

    attribute_map = {
        'internal_name': 'internal_name',
        'node': 'node',
        'size': 'size',
        'type': 'type',
        'uuid': 'uuid',
        'address': 'address',
        'location': 'location',
        'product_id': 'product_id',
        'drive_id': 'drive_id',
        'partition_count_degraded': 'partition_count_degraded',
        'partition_count_critical': 'partition_count_critical'
    }

    def __init__(self, internal_name=None, node=None, size=None, type=None, uuid=None, address=None, location=None, product_id=None, drive_id=None, partition_count_degraded=None, partition_count_critical=None, _configuration=None):  # noqa: E501
        """InlineResponse200131Drives - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._internal_name = None
        self._node = None
        self._size = None
        self._type = None
        self._uuid = None
        self._address = None
        self._location = None
        self._product_id = None
        self._drive_id = None
        self._partition_count_degraded = None
        self._partition_count_critical = None
        self.discriminator = None

        if internal_name is not None:
            self.internal_name = internal_name
        if node is not None:
            self.node = node
        if size is not None:
            self.size = size
        if type is not None:
            self.type = type
        if uuid is not None:
            self.uuid = uuid
        if address is not None:
            self.address = address
        if location is not None:
            self.location = location
        if product_id is not None:
            self.product_id = product_id
        if drive_id is not None:
            self.drive_id = drive_id
        if partition_count_degraded is not None:
            self.partition_count_degraded = partition_count_degraded
        if partition_count_critical is not None:
            self.partition_count_critical = partition_count_critical

    @property
    def internal_name(self):
        """Gets the internal_name of this InlineResponse200131Drives.  # noqa: E501


        :return: The internal_name of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """Sets the internal_name of this InlineResponse200131Drives.


        :param internal_name: The internal_name of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._internal_name = internal_name

    @property
    def node(self):
        """Gets the node of this InlineResponse200131Drives.  # noqa: E501


        :return: The node of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this InlineResponse200131Drives.


        :param node: The node of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._node = node

    @property
    def size(self):
        """Gets the size of this InlineResponse200131Drives.  # noqa: E501


        :return: The size of this InlineResponse200131Drives.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this InlineResponse200131Drives.


        :param size: The size of this InlineResponse200131Drives.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def type(self):
        """Gets the type of this InlineResponse200131Drives.  # noqa: E501


        :return: The type of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse200131Drives.


        :param type: The type of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def uuid(self):
        """Gets the uuid of this InlineResponse200131Drives.  # noqa: E501


        :return: The uuid of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InlineResponse200131Drives.


        :param uuid: The uuid of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def address(self):
        """Gets the address of this InlineResponse200131Drives.  # noqa: E501


        :return: The address of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this InlineResponse200131Drives.


        :param address: The address of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def location(self):
        """Gets the location of this InlineResponse200131Drives.  # noqa: E501


        :return: The location of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this InlineResponse200131Drives.


        :param location: The location of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def product_id(self):
        """Gets the product_id of this InlineResponse200131Drives.  # noqa: E501


        :return: The product_id of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """Sets the product_id of this InlineResponse200131Drives.


        :param product_id: The product_id of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._product_id = product_id

    @property
    def drive_id(self):
        """Gets the drive_id of this InlineResponse200131Drives.  # noqa: E501


        :return: The drive_id of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._drive_id

    @drive_id.setter
    def drive_id(self, drive_id):
        """Sets the drive_id of this InlineResponse200131Drives.


        :param drive_id: The drive_id of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._drive_id = drive_id

    @property
    def partition_count_degraded(self):
        """Gets the partition_count_degraded of this InlineResponse200131Drives.  # noqa: E501


        :return: The partition_count_degraded of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._partition_count_degraded

    @partition_count_degraded.setter
    def partition_count_degraded(self, partition_count_degraded):
        """Sets the partition_count_degraded of this InlineResponse200131Drives.


        :param partition_count_degraded: The partition_count_degraded of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._partition_count_degraded = partition_count_degraded

    @property
    def partition_count_critical(self):
        """Gets the partition_count_critical of this InlineResponse200131Drives.  # noqa: E501


        :return: The partition_count_critical of this InlineResponse200131Drives.  # noqa: E501
        :rtype: str
        """
        return self._partition_count_critical

    @partition_count_critical.setter
    def partition_count_critical(self, partition_count_critical):
        """Sets the partition_count_critical of this InlineResponse200131Drives.


        :param partition_count_critical: The partition_count_critical of this InlineResponse200131Drives.  # noqa: E501
        :type: str
        """

        self._partition_count_critical = partition_count_critical

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200131Drives, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200131Drives):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200131Drives):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20033Images(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'size': 'int',
        'checksum': 'str',
        'internal_id': 'int',
        'image_type': 'str',
        'default_vpsa_image': 'bool',
        'default_zios_image': 'bool',
        'default_zios_gen2_image': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'size': 'size',
        'checksum': 'checksum',
        'internal_id': 'internal_id',
        'image_type': 'image_type',
        'default_vpsa_image': 'default_vpsa_image',
        'default_zios_image': 'default_zios_image',
        'default_zios_gen2_image': 'default_zios_gen2_image'
    }

    def __init__(self, name=None, size=None, checksum=None, internal_id=None, image_type=None, default_vpsa_image=None, default_zios_image=None, default_zios_gen2_image=None, _configuration=None):  # noqa: E501
        """InlineResponse20033Images - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._size = None
        self._checksum = None
        self._internal_id = None
        self._image_type = None
        self._default_vpsa_image = None
        self._default_zios_image = None
        self._default_zios_gen2_image = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if size is not None:
            self.size = size
        if checksum is not None:
            self.checksum = checksum
        if internal_id is not None:
            self.internal_id = internal_id
        if image_type is not None:
            self.image_type = image_type
        if default_vpsa_image is not None:
            self.default_vpsa_image = default_vpsa_image
        if default_zios_image is not None:
            self.default_zios_image = default_zios_image
        if default_zios_gen2_image is not None:
            self.default_zios_gen2_image = default_zios_gen2_image

    @property
    def name(self):
        """Gets the name of this InlineResponse20033Images.  # noqa: E501


        :return: The name of this InlineResponse20033Images.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20033Images.


        :param name: The name of this InlineResponse20033Images.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def size(self):
        """Gets the size of this InlineResponse20033Images.  # noqa: E501


        :return: The size of this InlineResponse20033Images.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this InlineResponse20033Images.


        :param size: The size of this InlineResponse20033Images.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def checksum(self):
        """Gets the checksum of this InlineResponse20033Images.  # noqa: E501


        :return: The checksum of this InlineResponse20033Images.  # noqa: E501
        :rtype: str
        """
        return self._checksum

    @checksum.setter
    def checksum(self, checksum):
        """Sets the checksum of this InlineResponse20033Images.


        :param checksum: The checksum of this InlineResponse20033Images.  # noqa: E501
        :type: str
        """

        self._checksum = checksum

    @property
    def internal_id(self):
        """Gets the internal_id of this InlineResponse20033Images.  # noqa: E501


        :return: The internal_id of this InlineResponse20033Images.  # noqa: E501
        :rtype: int
        """
        return self._internal_id

    @internal_id.setter
    def internal_id(self, internal_id):
        """Sets the internal_id of this InlineResponse20033Images.


        :param internal_id: The internal_id of this InlineResponse20033Images.  # noqa: E501
        :type: int
        """

        self._internal_id = internal_id

    @property
    def image_type(self):
        """Gets the image_type of this InlineResponse20033Images.  # noqa: E501


        :return: The image_type of this InlineResponse20033Images.  # noqa: E501
        :rtype: str
        """
        return self._image_type

    @image_type.setter
    def image_type(self, image_type):
        """Sets the image_type of this InlineResponse20033Images.


        :param image_type: The image_type of this InlineResponse20033Images.  # noqa: E501
        :type: str
        """

        self._image_type = image_type

    @property
    def default_vpsa_image(self):
        """Gets the default_vpsa_image of this InlineResponse20033Images.  # noqa: E501


        :return: The default_vpsa_image of this InlineResponse20033Images.  # noqa: E501
        :rtype: bool
        """
        return self._default_vpsa_image

    @default_vpsa_image.setter
    def default_vpsa_image(self, default_vpsa_image):
        """Sets the default_vpsa_image of this InlineResponse20033Images.


        :param default_vpsa_image: The default_vpsa_image of this InlineResponse20033Images.  # noqa: E501
        :type: bool
        """

        self._default_vpsa_image = default_vpsa_image

    @property
    def default_zios_image(self):
        """Gets the default_zios_image of this InlineResponse20033Images.  # noqa: E501


        :return: The default_zios_image of this InlineResponse20033Images.  # noqa: E501
        :rtype: bool
        """
        return self._default_zios_image

    @default_zios_image.setter
    def default_zios_image(self, default_zios_image):
        """Sets the default_zios_image of this InlineResponse20033Images.


        :param default_zios_image: The default_zios_image of this InlineResponse20033Images.  # noqa: E501
        :type: bool
        """

        self._default_zios_image = default_zios_image

    @property
    def default_zios_gen2_image(self):
        """Gets the default_zios_gen2_image of this InlineResponse20033Images.  # noqa: E501


        :return: The default_zios_gen2_image of this InlineResponse20033Images.  # noqa: E501
        :rtype: bool
        """
        return self._default_zios_gen2_image

    @default_zios_gen2_image.setter
    def default_zios_gen2_image(self, default_zios_gen2_image):
        """Sets the default_zios_gen2_image of this InlineResponse20033Images.


        :param default_zios_gen2_image: The default_zios_gen2_image of this InlineResponse20033Images.  # noqa: E501
        :type: bool
        """

        self._default_zios_gen2_image = default_zios_gen2_image

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20033Images, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20033Images):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20033Images):
            return True

        return self.to_dict() != other.to_dict()
